@@ -15,6 +15,9 @@ our @EXPORT = qw(
     $POST_LEN_LIMIT
     $MAX_SELECT_LIMIT
     $PASSWORD_MIN_LEN
+    $VIEW_MAX_LEN
+    $ACTION_MAX_LEN
+    $ACTION_CMD_COUNT_LIMIT
 );
 
 our $MODEL_LIMIT = 40;
@@ -27,5 +30,8 @@ our $RECORD_LIMIT = 200;
 our $POST_LEN_LIMIT = 1_000_000; # 1 MB
 our $MAX_SELECT_LIMIT = 500;
 our $PASSWORD_MIN_LEN = 6;
+our $VIEW_MAX_LEN = 5_000; # 5 KB
+our $ACTION_MAX_LEN = 5_000; # 5 KB
+our $ACTION_CMD_COUNT_LIMIT = 5;
 
 1;
